# Changelog

## [0.0.5](https://github.com/cesan3/salt-ext-elasticsearch/compare/0.0.4...0.0.5) - 2023-11-06
- fix: add flush_synced method to ES6 module by @cesan3 in https://github.com/cesan3/salt-ext-elasticsearch/pull/8

## [0.0.4](https://github.com/cesan3/salt-ext-elasticsearch/compare/0.0.3...0.0.4) - 2023-11-06
- fix: update test workflow by @cesan3 in https://github.com/cesan3/salt-ext-elasticsearch/pull/6

## [0.0.3](https://github.com/cesan3/salt-ext-elasticsearch/compare/0.0.2...0.0.3) - 2023-11-06
- Update release.yml by @cesan3 in https://github.com/cesan3/salt-ext-elasticsearch/pull/4

## [0.0.2](https://github.com/cesan3/salt-ext-elasticsearch/compare/0.0.1...0.0.2) - 2023-11-06
- feat: Adding elasticsearch extension module by @cesan3 in https://github.com/cesan3/salt-ext-elasticsearch/pull/1
- fix: update README by @cesan3 in https://github.com/cesan3/salt-ext-elasticsearch/pull/2

## [0.0.1](https://github.com/cesan3/salt-ext-elasticsearch/commits/0.0.1) - 2023-11-04
